.. _spider_python-patterns.guide:

python-patterns.guide
---------------------
The latest articles from python-patterns.guide_. Since articles on
python-patterns.guide_ do not have a publication date, the ``Last-Modified``
header is used for the updated field which might not be accurate or stable.
I.e. old articles might have a newer value in the updated field even if they
were not updated.

Configuration
~~~~~~~~~~~~~
Add ``python-patterns.guide`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     python-patterns.guide

.. _python-patterns.guide: http://python-patterns.guide
